==> calligra-2.8.7.tar.xz: calligra-2.8.7/libs/koreport/wrtembed/KoReportDesignerItemLine.h <==
/*
 * OpenRPT report writer and rendering engine
 * Copyright (C) 2001-2007 by OpenMFG, LLC (info@openmfg.com)
 * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef __REPORTENTITYLINE_H__
#define __REPORTENTITYLINE_H__

#include <QGraphicsLineItem>
#include <koproperty/Property.h>
#include <koproperty/Set.h>
#include "KoReportDesignerItemBase.h"
#include "KoReportItemLine.h"

class KoReportDesigner;

//
// ReportEntityLine
//
class KoReportDesignerItemLine : public KoReportItemLine, public QGraphicsLineItem, public KoReportDesignerItemBase
{
    Q_OBJECT
public:
    KoReportDesignerItemLine(KoReportDesigner *, QGraphicsScene * scene, const QPointF &pos);
    KoReportDesignerItemLine(KoReportDesigner * d, QGraphicsScene * scene, const QPointF &startPos, const QPointF &endPos);
    KoReportDesignerItemLine(QDomNode & element, KoReportDesigner *, QGraphicsScene * scene);

    virtual void buildXML(QDomDocument & doc, QDomElement & parent);
    virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget *widget = 0);
    virtual KoReportDesignerItemLine* clone();

    void setLineScene(QLineF);
    
    virtual void move(const QPointF&);

private:
    KoReportDesigner* m_rd;
    void init(QGraphicsScene*, KoReportDesigner *);
    int grabHandle(QPointF pos);

    int m_grabAction;

protected:
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
    
private slots:
    void slotPropertyChanged(KoProperty::Set &, KoProperty::Property &);
};

#endif

==> calligra-2.9.0.tar.xz: calligra-2.9.0/libs/koreport/wrtembed/KoReportDesignerItemLine.h <==
/*
 * OpenRPT report writer and rendering engine
 * Copyright (C) 2001-2007 by OpenMFG, LLC (info@openmfg.com)
 * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __KOREPORTDESIGNERITEMLINE_H__
#define __KOREPORTDESIGNERITEMLINE_H__

#include <QGraphicsLineItem>
#include <koproperty/Property.h>
#include <koproperty/Set.h>
#include "KoReportDesignerItemBase.h"
#include "KoReportItemLine.h"

class KoReportDesigner;

//
// ReportEntityLine
//
class KoReportDesignerItemLine : public KoReportItemLine, public QGraphicsLineItem, public KoReportDesignerItemBase
{
    Q_OBJECT
public:
    KoReportDesignerItemLine(KoReportDesigner *, QGraphicsScene * scene, const QPointF &pos);
    KoReportDesignerItemLine(KoReportDesigner * d, QGraphicsScene * scene, const QPointF &startPos, const QPointF &endPos);
    KoReportDesignerItemLine(QDomNode & element, KoReportDesigner *, QGraphicsScene * scene);

    virtual void buildXML(QDomDocument & doc, QDomElement & parent);
    virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget *widget = 0);
    virtual KoReportDesignerItemLine* clone();

    void setLineScene(QLineF);
    
    virtual void move(const QPointF&);

private:
    KoReportDesigner* m_rd;
    void init(QGraphicsScene*, KoReportDesigner *);
    int grabHandle(QPointF pos);

    int m_grabAction;

protected:
    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent * event);
    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
    virtual void mousePressEvent(QGraphicsSceneMouseEvent * event);
    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
    virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
    
private slots:
    void slotPropertyChanged(KoProperty::Set &, KoProperty::Property &);
};

#endif
